@@ -60,7 +60,7 @@ B                   `         '
        888b  R'"B        ,',        R"'B  d888
       j888888bd8gf"'   ':'   `"?g8bd888888k
         R'Y'B   .8'     d' 'b     '8.   R'Y'X
-         R!B   .8' RdbB  d'; ;`b  RdbB '8.   R!
+         R!B   .8' RdbB  d'; ;`b  RdbB '8.   R!B
             d88  R`'B  8 ; ; 8  R`'B  88b             Rbutterfly Zv %sB
            d888b   .g8 ',' 8g.   d888b
           :888888888Y'     'Y888888888:           AConnecting to:B
@@ -108,7 +108,7 @@ class TermWebSocket(Route, tornado.websocket.WebSocketHandler):
             try:
                 self.callee = utils.User(name=user)
             except:
-                self.callee = utils.User(name='daemon')
+                self.callee = utils.User(name='nobody')
 
         try:
             os.chdir(self.path or self.callee.dir)
@@ -153,7 +153,6 @@ class TermWebSocket(Route, tornado.websocket.WebSocketHandler):
         else:
             args = ['/bin/su']
 
-        # This would be better to run
         if sys.platform == 'linux':
             args.append('-p')
             if tornado.options.options.shell:
@@ -163,7 +162,7 @@ class TermWebSocket(Route, tornado.websocket.WebSocketHandler):
         os.execvpe(args[0], args, env)
 
     def communicate(self):
-        self.log.debug('Adding handler')
+        self.log.info('Adding handler')
         fcntl.fcntl(self.fd, fcntl.F_SETFL, os.O_NONBLOCK)
 
         def utf8_error(e):
@@ -208,11 +207,9 @@ class TermWebSocket(Route, tornado.websocket.WebSocketHandler):
                     if field[0][0] == 'commonName':
                         self.user = self.callee = field[0][1]
 
-        if self.socket.local and self.socket.uid is not None:
-            self.caller = utils.User(uid=self.socket.uid)
-        else:
-            # We don't know uid is on the other machine
-            pass
+        # If local we have the user connecting
+        if self.socket.local and self.socket.user is not None:
+            self.caller = self.socket.user
 
         if self.user:
             try:
@@ -248,13 +245,14 @@ class TermWebSocket(Route, tornado.websocket.WebSocketHandler):
             try:
                 read = self.reader.read()
             except IOError:
-                pass
+                read = ''
+
+            self.log.info('READ>%r' % read)
+            if len(read) != 0 and self.ws_connection:
+                self.write_message(read.decode('utf-8', 'replace'))
             else:
-                self.log.info('READ>%r' % read)
-                if self.ws_connection:
-                    self.write_message(read.decode('utf-8', 'replace'))
-                else:
-                    events = ioloop.ERROR
+                events = ioloop.ERROR
+
         if events & ioloop.ERROR:
             self.log.info('Error on fd, closing')
             # Terminated
@@ -263,25 +261,27 @@ class TermWebSocket(Route, tornado.websocket.WebSocketHandler):
 
     def on_close(self):
         if getattr(self, 'pid', 0) == 0:
-            self.log.warning('pid is 0')
+            self.log.info('pid is 0')
             return
         try:
             self.writer.write(u('\x04'))
             self.writer.flush()
         except Exception:
-            self.log.warning('closing term fail', exc_info=True)
+            self.log.debug('closing term fail', exc_info=True)
+
         try:
             os.close(self.fd)
         except Exception:
-            self.log.warning('closing fd fail', exc_info=True)
+            self.log.debug('closing fd fail', exc_info=True)
+
         try:
             os.waitpid(self.pid, 0)
         except Exception:
-            self.log.warning('waitpid fail', exc_info=True)
+            self.log.debug('waitpid fail', exc_info=True)
 
         try:
             ioloop.remove_handler(self.fd)
         except Exception:
-            self.log.warning('handler removal fail', exc_info=True)
+            self.log.debug('handler removal fail', exc_info=True)
 
         self.log.info('Websocket closed')
